<?php
/**
 * A filter for password change detection
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, this is free software
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class PasswordChangeFilter extends BaseFilter implements Filterable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this filter class
	 *
	 * @param	$controllerInstance		An instance of a controller class
	 * @return	$filterInstance			An instance of this filter class
	 */
	public final static function createPasswordChangeFilter () {
		// Get a new instance
		$filterInstance = new PasswordChangeFilter();

		// Return the instance
		return $filterInstance;
	}

	/**
	 * Executes the filter with given request and response objects
	 *
	 * @param	$requestInstance	An instance of a class with an Requestable interface
	 * @param	$responseInstance	An instance of a class with an Responseable interface
	 * @return	void
	 * @todo	Finished updating user password hash here. HINT: Use the User class again.
	 */
	public function execute (Requestable $requestInstance, Responseable $responseInstance) {
		// Get both passwords
		$pass1 = $requestInstance->getRequestElement('pass1');
		$pass2 = $requestInstance->getRequestElement('pass2');

		// Is only first email set?
		if ((!empty($pass1)) && (empty($pass2))) {
			// Request is invalid!
			$requestInstance->requestIsValid(false);

			// Email 2 is empty
			$responseInstance->addFatalMessage('pass2_empty');

			// Stop processing here
			return false;
		} // END - if

		// Is only second pass set?
		if ((empty($pass1)) && (!empty($pass2))) {
			// Request is invalid!
			$requestInstance->requestIsValid(false);

			// Email 1 is empty
			$responseInstance->addFatalMessage('pass1_empty');

			// Stop processing here
			return false;
		} // END - if

		// Are password and confirmation empty?
		if ((empty($pass1)) && (empty($pass2))) {
			// Don't change password here
			return true;
		} // END - if

		// Do both match?
		if ($pass1 != $pass2) {
			// Request is invalid!
			$requestInstance->requestIsValid(false);

			// Emails are mismatching
			$responseInstance->addFatalMessage('pass_mismatch');

			// Stop processing here
			return false;
		} // END - if

		// Now, get a user instance for comparison
		$userInstance = Registry::getRegistry()->getInstance('user');

		// Update the "password" field
		$this->partialStub("Unfinished part.");
	}
}

// [EOF]
?>
